@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,6 +21,7 @@ import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertThrowsExactly;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assumptions.assumeFalse;
 import static org.junit.jupiter.api.Assumptions.assumeTrue;
@@ -31,12 +32,16 @@ import java.io.InputStream;
 import java.io.Reader;
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 
 import org.apache.commons.io.ByteOrderMark;
+import org.apache.commons.io.IOUtils;
+import org.apache.commons.io.test.CustomIOException;
+import org.apache.commons.lang3.SystemProperties;
 import org.junit.jupiter.api.Test;
 import org.w3c.dom.Document;
 import org.xml.sax.InputSource;
@@ -47,21 +52,21 @@ import org.xml.sax.SAXParseException;
  * Test case for {@link BOMInputStream}.
  */
 @SuppressWarnings("ResultOfMethodCallIgnored")
-public class BOMInputStreamTest {
+class BOMInputStreamTest {
 
     /**
      *  A mock InputStream that expects {@code close()} to be called.
      */
     private static final class ExpectCloseInputStream extends InputStream {
-        private boolean _closeCalled;
+        private boolean closed;
 
         public void assertCloseCalled() {
-            assertTrue(_closeCalled);
+            assertTrue(closed);
         }
 
         @Override
         public void close() throws IOException {
-            _closeCalled = true;
+            closed = true;
         }
 
         @Override
@@ -189,9 +194,9 @@ public class BOMInputStreamTest {
             try (BOMInputStream bomInputStream = BOMInputStream.builder().setInputStream(inputStream).get()) {
                 bomInputStream.mark(1_000_000);
 
-                this.readFile(bomInputStream);
+                readFile(bomInputStream);
                 bomInputStream.reset();
-                this.readFile(bomInputStream);
+                readFile(bomInputStream);
                 inputStream.close();
             }
         }
@@ -206,7 +211,45 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testAvailableWithBOM() throws Exception {
+    void testAfterReadConsumer() throws Exception {
+        final byte[] data = { 'A', 'B', 'C', 'D' };
+        final AtomicBoolean boolRef = new AtomicBoolean();
+        // @formatter:off
+        try (InputStream bounded = BOMInputStream.builder()
+                .setInputStream(createUtf8Input(data, true))
+                .setAfterRead(i -> boolRef.set(true))
+                .get()) {
+            IOUtils.consume(bounded);
+        }
+        // @formatter:on
+        assertTrue(boolRef.get());
+        // Throwing
+        final String message = "test exception message";
+        // @formatter:off
+        try (InputStream bounded = BOMInputStream.builder()
+                .setInputStream(createUtf8Input(data, true))
+                .setAfterRead(i -> {
+                    throw new CustomIOException(message);
+                })
+                .get()) {
+            assertEquals(message, assertThrowsExactly(CustomIOException.class, () -> IOUtils.consume(bounded)).getMessage());
+        }
+        // @formatter:on
+    }
+
+    @Test
+    void testAvailableWithBOMAfterClose() throws Exception {
+        final byte[] data = { 'A', 'B', 'C', 'D' };
+        final InputStream shadow;
+        try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
+            assertEquals(7, in.available());
+            shadow = in;
+        }
+        assertEquals(0, shadow.available());
+    }
+
+    @Test
+    void testAvailableWithBOMAfterOpen() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             assertEquals(7, in.available());
@@ -214,16 +257,22 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testAvailableWithoutBOM() throws Exception {
+    void testAvailableWithoutBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertEquals(4, in.available());
         }
     }
 
+    @Test
+    void testBuilderGet() {
+        // java.lang.IllegalStateException: origin == null
+        assertThrows(IllegalStateException.class, () -> BOMInputStream.builder().get());
+    }
+
     @Test
     // this is here for coverage
-    public void testClose() throws Exception {
+    void testClose() throws Exception {
         try (ExpectCloseInputStream del = new ExpectCloseInputStream()) {
             try (InputStream in = new BOMInputStream(del)) {
                 // nothing
@@ -233,7 +282,12 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testEmptyBufferWithBOM() throws Exception {
+    void testCloseHandleIOException() throws IOException {
+        ProxyInputStreamTest.testCloseHandleIOException(BOMInputStream.builder());
+    }
+
+    @Test
+    void testEmptyBufferWithBOM() throws Exception {
         final byte[] data = {};
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             final byte[] buf = new byte[1024];
@@ -242,7 +296,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testEmptyBufferWithoutBOM() throws Exception {
+    void testEmptyBufferWithoutBOM() throws Exception {
         final byte[] data = {};
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             final byte[] buf = new byte[1024];
@@ -251,7 +305,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testGetBOMFirstThenRead() throws Exception {
+    void testGetBOMFirstThenRead() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             assertEquals(ByteOrderMark.UTF_8, in.getBOM(), "getBOM");
@@ -265,7 +319,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testGetBOMFirstThenReadInclude() throws Exception {
+    void testGetBOMFirstThenReadInclude() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).setInclude(true).get()) {
             assertTrue(in.hasBOM(), "hasBOM()");
@@ -282,7 +336,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testLargeBufferWithBOM() throws Exception {
+    void testLargeBufferWithBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             final byte[] buf = new byte[1024];
@@ -291,7 +345,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testLargeBufferWithoutBOM() throws Exception {
+    void testLargeBufferWithoutBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             final byte[] buf = new byte[1024];
@@ -300,7 +354,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testLeadingNonBOMBufferedRead() throws Exception {
+    void testLeadingNonBOMBufferedRead() throws Exception {
         final byte[] data = { (byte) 0xEF, (byte) 0xAB, (byte) 0xCD };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             final byte[] buf = new byte[1024];
@@ -309,7 +363,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testLeadingNonBOMSingleRead() throws Exception {
+    void testLeadingNonBOMSingleRead() throws Exception {
         final byte[] data = { (byte) 0xEF, (byte) 0xAB, (byte) 0xCD };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertEquals(0xEF, in.read());
@@ -320,7 +374,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testMarkResetAfterReadWithBOM() throws Exception {
+    void testMarkResetAfterReadWithBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             assertTrue(in.markSupported());
@@ -336,7 +390,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testMarkResetAfterReadWithoutBOM() throws Exception {
+    void testMarkResetAfterReadWithoutBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertTrue(in.markSupported());
@@ -352,7 +406,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testMarkResetBeforeReadWithBOM() throws Exception {
+    void testMarkResetBeforeReadWithBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             assertTrue(in.markSupported());
@@ -367,7 +421,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testMarkResetBeforeReadWithoutBOM() throws Exception {
+    void testMarkResetBeforeReadWithoutBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertTrue(in.markSupported());
@@ -382,12 +436,12 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testNoBoms() throws Exception {
+    void testNoBoms() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         assertThrows(IllegalArgumentException.class, () -> new BOMInputStream(createUtf8Input(data, true), false, (ByteOrderMark[]) null).close());
         assertThrows(IllegalArgumentException.class, () -> new BOMInputStream(createUtf8Input(data, true), false, new ByteOrderMark[0]).close());
         //
-        try (final BOMInputStream bomInputStream = BOMInputStream.builder()
+        try (BOMInputStream bomInputStream = BOMInputStream.builder()
                 .setInputStream(createUtf8Input(data, true))
                 .setInclude(true)
                 .setByteOrderMarks((ByteOrderMark[]) null)
@@ -403,7 +457,17 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadEmpty() throws Exception {
+    void testReadAfterClose() throws Exception {
+        final byte[] data = { 'A', 'B', 'C', 'D' };
+        try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
+            assertEquals(7, in.available());
+            in.close();
+            assertThrows(IOException.class, in::read);
+        }
+    }
+
+    @Test
+    void testReadEmpty() throws Exception {
         final byte[] data = {};
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertEquals(-1, in.read());
@@ -414,7 +478,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadSmall() throws Exception {
+    void testReadSmall() throws Exception {
         final byte[] data = { 'A', 'B' };
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertEquals('A', in.read());
@@ -427,17 +491,17 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadTwiceWithBOM() throws Exception {
-        this.readBOMInputStreamTwice("/org/apache/commons/io/testfileBOM.xml");
+    void testReadTwiceWithBOM() throws Exception {
+        readBOMInputStreamTwice("/org/apache/commons/io/testfileBOM.xml");
     }
 
     @Test
-    public void testReadTwiceWithoutBOM() throws Exception {
-        this.readBOMInputStreamTwice("/org/apache/commons/io/testfileNoBOM.xml");
+    void testReadTwiceWithoutBOM() throws Exception {
+        readBOMInputStreamTwice("/org/apache/commons/io/testfileNoBOM.xml");
     }
 
     @Test
-    public void testReadWithBOMInclude() throws Exception {
+    void testReadWithBOMInclude() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (BOMInputStream in = new BOMInputStream(createUtf8Input(data, true), true)) {
             assertEquals(0xEF, in.read());
@@ -454,7 +518,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadWithBOMUtf16Be() throws Exception {
+    void testReadWithBOMUtf16Be() throws Exception {
         final byte[] data = "ABC".getBytes(StandardCharsets.UTF_16BE);
         try (BOMInputStream in = new BOMInputStream(createUtf16BeDataStream(data, true), ByteOrderMark.UTF_16BE)) {
             assertEquals(0, in.read());
@@ -472,7 +536,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadWithBOMUtf16Le() throws Exception {
+    void testReadWithBOMUtf16Le() throws Exception {
         final byte[] data = "ABC".getBytes(StandardCharsets.UTF_16LE);
         try (BOMInputStream in = new BOMInputStream(createUtf16LeDataStream(data, true), ByteOrderMark.UTF_16LE)) {
             assertEquals('A', in.read());
@@ -490,7 +554,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadWithBOMUtf32Be() throws Exception {
+    void testReadWithBOMUtf32Be() throws Exception {
         assumeTrue(Charset.isSupported("UTF_32BE"));
         final byte[] data = "ABC".getBytes("UTF_32BE");
         try (BOMInputStream in = new BOMInputStream(createUtf32BeDataStream(data, true),
@@ -516,7 +580,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadWithBOMUtf32Le() throws Exception {
+    void testReadWithBOMUtf32Le() throws Exception {
         assumeTrue(Charset.isSupported("UTF_32LE"));
         final byte[] data = "ABC".getBytes("UTF_32LE");
         try (BOMInputStream in = new BOMInputStream(createUtf32LeDataStream(data, true),
@@ -542,7 +606,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadWithBOMUtf8() throws Exception {
+    void testReadWithBOMUtf8() throws Exception {
         final byte[] data = "ABC".getBytes(StandardCharsets.UTF_8);
         try (BOMInputStream in = new BOMInputStream(createUtf8Input(data, true), ByteOrderMark.UTF_8)) {
             assertEquals('A', in.read());
@@ -557,7 +621,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadWithMultipleBOM() throws Exception {
+    void testReadWithMultipleBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (BOMInputStream in = new BOMInputStream(createUtf8Input(data, true), ByteOrderMark.UTF_16BE,
                 ByteOrderMark.UTF_8)) {
@@ -573,7 +637,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadWithoutBOM() throws Exception {
+    void testReadWithoutBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertEquals('A', in.read());
@@ -587,8 +651,8 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithBOMUcs2() throws Exception {
-        assumeFalse(System.getProperty("java.vendor").contains("IBM"), "This test does not pass on some IBM VMs xml parsers");
+    void testReadXmlWithBOMUcs2() throws Exception {
+        assumeFalse(SystemProperties.getJavaVendor().contains("IBM"), "This test does not pass on some IBM VMs XML parsers");
 
         // UCS-2 is BE.
         assumeTrue(Charset.isSupported("ISO-10646-UCS-2"));
@@ -600,7 +664,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithBOMUcs4() throws Exception {
+    void testReadXmlWithBOMUcs4() throws Exception {
         // UCS-4 is BE or LE?
         // Hm: ISO-10646-UCS-4 is not supported on Oracle 1.6.0_31
         assumeTrue(Charset.isSupported("ISO-10646-UCS-4"));
@@ -615,7 +679,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithBOMUtf16Be() throws Exception {
+    void testReadXmlWithBOMUtf16Be() throws Exception {
         final byte[] data = "<?xml version=\"1.0\" encoding=\"UTF-16BE\"?><X/>".getBytes(StandardCharsets.UTF_16BE);
         try (BOMInputStream in = new BOMInputStream(createUtf16BeDataStream(data, true), ByteOrderMark.UTF_16BE)) {
             parseXml(in);
@@ -624,7 +688,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithBOMUtf16Le() throws Exception {
+    void testReadXmlWithBOMUtf16Le() throws Exception {
         final byte[] data = "<?xml version=\"1.0\" encoding=\"UTF-16LE\"?><X/>".getBytes(StandardCharsets.UTF_16LE);
         try (BOMInputStream in = new BOMInputStream(createUtf16LeDataStream(data, true), ByteOrderMark.UTF_16LE)) {
             parseXml(in);
@@ -633,7 +697,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithBOMUtf32Be() throws Exception {
+    void testReadXmlWithBOMUtf32Be() throws Exception {
         assumeTrue(jvmAndSaxBothSupportCharset("UTF_32BE"), "JVM and SAX need to support UTF_32BE for this");
         final byte[] data = "<?xml version=\"1.0\" encoding=\"UTF-32BE\"?><X/>".getBytes("UTF_32BE");
         try (BOMInputStream in = new BOMInputStream(createUtf32BeDataStream(data, true), ByteOrderMark.UTF_32BE)) {
@@ -646,7 +710,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithBOMUtf32Le() throws Exception {
+    void testReadXmlWithBOMUtf32Le() throws Exception {
         assumeTrue(jvmAndSaxBothSupportCharset("UTF_32LE"), "JVM and SAX need to support UTF_32LE for this");
         final byte[] data = "<?xml version=\"1.0\" encoding=\"UTF-32LE\"?><X/>".getBytes("UTF_32LE");
         try (BOMInputStream in = new BOMInputStream(createUtf32LeDataStream(data, true), ByteOrderMark.UTF_32LE)) {
@@ -659,7 +723,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithBOMUtf8() throws Exception {
+    void testReadXmlWithBOMUtf8() throws Exception {
         final byte[] data = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><X/>".getBytes(StandardCharsets.UTF_8);
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             parseXml(in);
@@ -668,7 +732,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithoutBOMUtf32Be() throws Exception {
+    void testReadXmlWithoutBOMUtf32Be() throws Exception {
         assumeTrue(jvmAndSaxBothSupportCharset("UTF_32BE"), "JVM and SAX need to support UTF_32BE for this");
         final byte[] data = "<?xml version=\"1.0\" encoding=\"UTF_32BE\"?><X/>".getBytes("UTF_32BE");
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
@@ -678,7 +742,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testReadXmlWithoutBOMUtf32Le() throws Exception {
+    void testReadXmlWithoutBOMUtf32Le() throws Exception {
         assumeTrue(jvmAndSaxBothSupportCharset("UTF_32LE"), "JVM and SAX need to support UTF_32LE for this");
         final byte[] data = "<?xml version=\"1.0\" encoding=\"UTF-32LE\"?><X/>".getBytes("UTF_32LE");
         try (BOMInputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
@@ -687,9 +751,8 @@ public class BOMInputStreamTest {
         parseXml(createUtf32BeDataStream(data, false));
     }
 
-
     @Test
-    public void testSkipReturnValueWithBom() throws IOException {
+    void testSkipReturnValueWithBom() throws IOException {
         final byte[] data = { (byte) 0x31, (byte) 0x32, (byte) 0x33 };
         try (BOMInputStream is1 = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             assertEquals(2, is1.skip(2));
@@ -698,7 +761,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testSkipReturnValueWithoutBom() throws IOException {
+    void testSkipReturnValueWithoutBom() throws IOException {
         final byte[] data = { (byte) 0x31, (byte) 0x32, (byte) 0x33 };
         try (BOMInputStream is2 = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             assertEquals(2, is2.skip(2)); // IO-428
@@ -707,7 +770,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testSkipWithBOM() throws Exception {
+    void testSkipWithBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             in.skip(2L);
@@ -716,7 +779,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testSkipWithoutBOM() throws Exception {
+    void testSkipWithoutBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C', 'D' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             in.skip(2L);
@@ -725,7 +788,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testSmallBufferWithBOM() throws Exception {
+    void testSmallBufferWithBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, true)).get()) {
             final byte[] buf = new byte[1024];
@@ -735,7 +798,7 @@ public class BOMInputStreamTest {
     }
 
     @Test
-    public void testSmallBufferWithoutBOM() throws Exception {
+    void testSmallBufferWithoutBOM() throws Exception {
         final byte[] data = { 'A', 'B', 'C' };
         try (InputStream in = BOMInputStream.builder().setInputStream(createUtf8Input(data, false)).get()) {
             final byte[] buf = new byte[1024];
@@ -746,7 +809,7 @@ public class BOMInputStreamTest {
 
     @Test
     // make sure that our support code works as expected
-    public void testSupportCode() throws Exception {
+    void testSupportCode() throws Exception {
         try (InputStream in = createUtf8Input(new byte[] { 'A', 'B' }, true)) {
             final byte[] buf = new byte[1024];
             final int len = in.read(buf);
